==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/ADVREPORTSESSION_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ADVREPORTSESSION_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ADVREPORTSESSION_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="SESSIONID" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="PREFERENCES" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="USERPREFERENCES" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="USERSESSIONID" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADVREPORTSESSION_Type", propOrder = {
    "sessionid",
    "preferences",
    "userpreferences",
    "usersessionid"
})
public class ADVREPORTSESSION_Type {

    @XmlElement(name = "SESSIONID", required = true)
    protected String sessionid;
    @XmlElement(name = "PREFERENCES", required = true)
    protected String preferences;
    @XmlElement(name = "USERPREFERENCES", required = true)
    protected String userpreferences;
    @XmlElement(name = "USERSESSIONID", required = true)
    protected String usersessionid;

    /**
     * Gets the value of the sessionid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSESSIONID() {
        return sessionid;
    }

    /**
     * Sets the value of the sessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSESSIONID(String value) {
        this.sessionid = value;
    }

    /**
     * Gets the value of the preferences property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREFERENCES() {
        return preferences;
    }

    /**
     * Sets the value of the preferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREFERENCES(String value) {
        this.preferences = value;
    }

    /**
     * Gets the value of the userpreferences property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERPREFERENCES() {
        return userpreferences;
    }

    /**
     * Sets the value of the userpreferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERPREFERENCES(String value) {
        this.userpreferences = value;
    }

    /**
     * Gets the value of the usersessionid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERSESSIONID() {
        return usersessionid;
    }

    /**
     * Sets the value of the usersessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERSESSIONID(String value) {
        this.usersessionid = value;
    }

}

==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/ADVREPORTSESSION_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ADVREPORTSESSION_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ADVREPORTSESSION_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="SESSIONID" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="PREFERENCES" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="USERPREFERENCES" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="USERSESSIONID" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADVREPORTSESSION_Type", propOrder = {
    "sessionid",
    "preferences",
    "userpreferences",
    "usersessionid"
})
public class ADVREPORTSESSION_Type {

    @XmlElement(name = "SESSIONID", required = true)
    protected String sessionid;
    @XmlElement(name = "PREFERENCES", required = true)
    protected String preferences;
    @XmlElement(name = "USERPREFERENCES", required = true)
    protected String userpreferences;
    @XmlElement(name = "USERSESSIONID", required = true)
    protected String usersessionid;

    /**
     * Obtient la valeur de la propriété sessionid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSESSIONID() {
        return sessionid;
    }

    /**
     * Définit la valeur de la propriété sessionid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSESSIONID(String value) {
        this.sessionid = value;
    }

    /**
     * Obtient la valeur de la propriété preferences.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREFERENCES() {
        return preferences;
    }

    /**
     * Définit la valeur de la propriété preferences.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREFERENCES(String value) {
        this.preferences = value;
    }

    /**
     * Obtient la valeur de la propriété userpreferences.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERPREFERENCES() {
        return userpreferences;
    }

    /**
     * Définit la valeur de la propriété userpreferences.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERPREFERENCES(String value) {
        this.userpreferences = value;
    }

    /**
     * Obtient la valeur de la propriété usersessionid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERSESSIONID() {
        return usersessionid;
    }

    /**
     * Définit la valeur de la propriété usersessionid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERSESSIONID(String value) {
        this.usersessionid = value;
    }

}
